<h1 align="center">BlackboxAI Interpreter</h1>

### Step1: Install
```shell
pip install blackboxai
```

### Step2: Start from the command line

```shell
blackboxai
```

<br>

**BlackboxAI Interpreter** lets BlackboxAI run code (Python, Javascript, Shell, and more) locally. You can chat with BlackboxAI Interpreter through a chat interface in your terminal by running `$ blackboxai` after installing.

This provides a natural-language interface to your computer's general-purpose capabilities:

- Create and edit code files, PDFs, etc.
- Control a Chrome browser to perform research
- Plot, clean, and analyze large datasets
- ...etc.
